window.Gleam.initSearch([{"doc":"bidict","title":"bidict","content":"# bidict\n[![Package Version](https://img.shields.io/hexpm/v/bidict)](https://hex.pm/packages/bidict)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/bidict/)\n\n\nA bijective dictionary. Each key corresponds to one value, and each value corresponds to one key. To achieve this, a `Bidict` stores two one-way mappings: `Bidict(a2b: Dict(a, b), b2a: Dict(b, a))`. All functions properly update both forward and reverse mappings.\n\nAPI is mostly the same as `gleam/dict`, though with a few differences:\n  - `delete` -&gt; `delete_a`, `delete_b`\n  - `drop` -&gt; `drop_a`, `drop_b`\n  - `get` -&gt; `get_a`, `get_b`\n  - `has_key` -&gt; `has_a`, `has_b`\n  - new `map_keys`\n  - new `map`\n\n## Install\n\n```sh\ngleam add bidict\n```\n\n## Usage\n```gleam\nimport bidict\n\npub fn main() {\n  let elements: Bidict(String, String) =\n    [\n      #(&quot;Hydrogen&quot;, &quot;H&quot;),\n      #(&quot;Carbon&quot;, &quot;C&quot;),\n      #(&quot;Bromine&quot;, &quot;Br&quot;),\n      #(&quot;Neodymium&quot;, &quot;Nd&quot;),\n    ]\n    |&gt; bidict.from_list\n\n  let assert Ok(&quot;Br&quot;) = bidict.get_a(elements, &quot;Bromine&quot;)\n  let assert Error(Nil) = bidict.get_a(elements, &quot;Oxygen&quot;)\n\n  let assert Ok(&quot;Carbon&quot;) = bidict.get_b(elements, &quot;C&quot;)\n  let assert Error(Nil) = bidict.get_b(elements, &quot;Al&quot;)\n\n  let assert True = bidict.has_a(elements, &quot;Hydrogen&quot;)\n  let assert False = bidict.has_b(elements, &quot;He&quot;)\n\n  let assert False =\n    elements\n    |&gt; bidict.delete_a(&quot;Neodymium&quot;)\n    |&gt; bidict.has_b(&quot;Ne&quot;)\n\n  let assert 3 =\n    elements\n    |&gt; bidict.insert(&quot;Bromine&quot;, &quot;Nd&quot;)\n    |&gt; bidict.size\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/bidict&gt;.\n\n## Implementations in Other Languages\n- [`Rust - bimap`](https://docs.rs/bimap/latest/bimap/index.html)\n- [`Python - bidict`](https://bidict.readthedocs.io/en/main/index.html)\n- [`Haskell - bimap`](https://hackage.haskell.org/package/bimap-0.5.0)\n","url":"index.html"},{"doc":"bidict","title":"Bidict","content":"pub type Bidict(a, b) {\n  Bidict(a2b: Dict(a, b), b2a: Dict(b, a))\n}\n\nBidict(a2b: Dict(a, b), b2a: Dict(b, a))\n\n\nSynonyms:\nbidict.Bidict\nbidict Bidict","url":"bidict.html#Bidict"},{"doc":"bidict","title":"delete_a","content":"pub fn delete_a(bdict: Bidict(a, b), a: a) -&gt; Bidict(a, b)\n\nSynonyms:\nbidict.delete_a\nbidict delete_a","url":"bidict.html#delete_a"},{"doc":"bidict","title":"delete_b","content":"pub fn delete_b(bdict: Bidict(a, b), b: b) -&gt; Bidict(a, b)\n\nSynonyms:\nbidict.delete_b\nbidict delete_b","url":"bidict.html#delete_b"},{"doc":"bidict","title":"drop_a","content":"pub fn drop_a(\n  bdict: Bidict(a, b),\n  disallowed_a: List(a),\n) -&gt; Bidict(a, b)\n\nSynonyms:\nbidict.drop_a\nbidict drop_a","url":"bidict.html#drop_a"},{"doc":"bidict","title":"drop_b","content":"pub fn drop_b(\n  bdict: Bidict(a, b),\n  disallowed_b: List(b),\n) -&gt; Bidict(a, b)\n\nSynonyms:\nbidict.drop_b\nbidict drop_b","url":"bidict.html#drop_b"},{"doc":"bidict","title":"filter","content":"pub fn filter(\n  in bdict: Bidict(a, b),\n  keeping predicate: fn(a, b) -&gt; Bool,\n) -&gt; Bidict(a, b)\n\nSynonyms:\nbidict.filter\nbidict filter","url":"bidict.html#filter"},{"doc":"bidict","title":"fold","content":"pub fn fold(\n  over bdict: Bidict(a, b),\n  from initial: c,\n  with fun: fn(c, a, b) -&gt; c,\n) -&gt; c\n\nSynonyms:\nbidict.fold\nbidict fold","url":"bidict.html#fold"},{"doc":"bidict","title":"from_list","content":"pub fn from_list(list: List(#(a, b))) -&gt; Bidict(a, b)\n\nSynonyms:\nbidict.from_list\nbidict from_list","url":"bidict.html#from_list"},{"doc":"bidict","title":"get_a","content":"pub fn get_a(bdict: Bidict(a, b), a: a) -&gt; Result(b, Nil)\n\nSynonyms:\nbidict.get_a\nbidict get_a","url":"bidict.html#get_a"},{"doc":"bidict","title":"get_b","content":"pub fn get_b(bdict: Bidict(a, b), b: b) -&gt; Result(a, Nil)\n\nSynonyms:\nbidict.get_b\nbidict get_b","url":"bidict.html#get_b"},{"doc":"bidict","title":"has_a","content":"pub fn has_a(bdict: Bidict(a, b), a: a) -&gt; Bool\n\nSynonyms:\nbidict.has_a\nbidict has_a","url":"bidict.html#has_a"},{"doc":"bidict","title":"has_b","content":"pub fn has_b(bdict: Bidict(a, b), b: b) -&gt; Bool\n\nSynonyms:\nbidict.has_b\nbidict has_b","url":"bidict.html#has_b"},{"doc":"bidict","title":"insert","content":"pub fn insert(bdict: Bidict(a, b), a: a, b: b) -&gt; Bidict(a, b)\n\nSynonyms:\nbidict.insert\nbidict insert","url":"bidict.html#insert"},{"doc":"bidict","title":"keys","content":"pub fn keys(bdict: Bidict(a, b)) -&gt; List(a)\n\nSynonyms:\nbidict.keys\nbidict keys","url":"bidict.html#keys"},{"doc":"bidict","title":"map","content":"pub fn map(bdict: Bidict(a, b), fun: fn(a, b) -&gt; c) -&gt; List(c)\n\nSynonyms:\nbidict.map\nbidict map","url":"bidict.html#map"},{"doc":"bidict","title":"map_keys","content":"pub fn map_keys(\n  bdict: Bidict(a, b),\n  fun: fn(a, b) -&gt; c,\n) -&gt; Bidict(c, b)\n\nSynonyms:\nbidict.map_keys\nbidict map_keys","url":"bidict.html#map_keys"},{"doc":"bidict","title":"map_values","content":"pub fn map_values(\n  bdict: Bidict(a, b),\n  fun: fn(a, b) -&gt; c,\n) -&gt; Bidict(a, c)\n\nSynonyms:\nbidict.map_values\nbidict map_values","url":"bidict.html#map_values"},{"doc":"bidict","title":"merge","content":"pub fn merge(\n  bdict: Bidict(a, b),\n  new_bdict: Bidict(a, b),\n) -&gt; Bidict(a, b)\n\nSynonyms:\nbidict.merge\nbidict merge","url":"bidict.html#merge"},{"doc":"bidict","title":"new","content":"pub fn new() -&gt; Bidict(a, b)\n\nSynonyms:\nbidict.new\nbidict new","url":"bidict.html#new"},{"doc":"bidict","title":"size","content":"pub fn size(bdict: Bidict(a, b)) -&gt; Int\n\nSynonyms:\nbidict.size\nbidict size","url":"bidict.html#size"},{"doc":"bidict","title":"take","content":"pub fn take(\n  from bdict: Bidict(a, b),\n  keeping desired_keys: List(a),\n) -&gt; Bidict(a, b)\n\nSynonyms:\nbidict.take\nbidict take","url":"bidict.html#take"},{"doc":"bidict","title":"to_list","content":"pub fn to_list(bdict: Bidict(a, b)) -&gt; List(#(a, b))\n\nSynonyms:\nbidict.to_list\nbidict to_list","url":"bidict.html#to_list"},{"doc":"bidict","title":"update","content":"pub fn update(\n  bidict: Bidict(a, b),\n  a: a,\n  fun: fn(Option(b)) -&gt; b,\n) -&gt; Bidict(a, b)\n\nSynonyms:\nbidict.update\nbidict update","url":"bidict.html#update"},{"doc":"bidict","title":"values","content":"pub fn values(bdict: Bidict(a, b)) -&gt; List(b)\n\nSynonyms:\nbidict.values\nbidict values","url":"bidict.html#values"},{"doc":"bidict","title":"bidict","content":"","url":"bidict.html"}]);